.. yodel documentation master file, created by
   sphinx-quickstart on Tue Aug 12 23:07:32 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to yodel's documentation!
=================================

Contents:

.. toctree::
   :maxdepth: 4

   yodel


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

